@@ -97,10 +97,11 @@ function install_deps {
         mingw-w64-"${ARCH}"-"${PYTHON_ID}"-pyopenssl \
         mingw-w64-"${ARCH}"-"${PYTHON_ID}"-docutils \
         mingw-w64-"${ARCH}"-"${PYTHON_ID}"-certifi \
-        mingw-w64-"${ARCH}"-"${PYTHON_ID}"-six
+        mingw-w64-"${ARCH}"-"${PYTHON_ID}"-six \
+        mingw-w64-"${ARCH}"-"${PYTHON_ID}"-pygments
 
     PIP_REQUIREMENTS="\
-nbxmpp==0.6.9
+git+https://dev.gajim.org/gajim/python-nbxmpp.git@nbxmpp_0.6
 git+https://dev.gajim.org/lovetox/pybonjour-python3.git
 git+https://github.com/enthought/pywin32-ctypes.git
 keyring
